## Welcome to ARK

Thanks for choosing `ark`! `ark` is one of several libraries developed by [Angelo Lab](https://www.angelolab.com) affiliated with the Department of Pathology at Stanford University which uses Multiplexed Ion Beam Imaging (MIBI) for medical imaging analysis. Specifically, `ark` is a toolkit that assists with pre-processing tasks and post-processing analyis of image data generated from MIBI. 
 
Want to get started? Please follow our quickstart guide as follows:

